Enum cryptographic_message_syntax::CmsError [−][src]
pub enum CmsError {
Show variants
DecodeErr(Error),
MissingSignedAttributeContentType,
MalformedSignedAttributeContentType,
MissingSignedAttributeMessageDigest,
MalformedSignedAttributeMessageDigest,
MalformedSignedAttributeSigningTime,
MalformedUnsignedAttributeTimeStampToken,
SubjectKeyIdentifierUnsupported,
Io(Error),
UnknownKeyAlgorithm(Oid),
UnknownDigestAlgorithm(Oid),
UnknownSignatureAlgorithm(Oid),
UnknownCertificateFormat,
CertificateNotFound,
SignatureVerificationError,
NoSignedAttributes,
DigestNotEqual,
Pem(PemError),
SignatureCreation,
CertificateMissingData,
DistinguishedNameParseError,
TimeStampProtocol(TimeStampError),
X509Certificate(X509CertificateError),
}Variants
DecodeErr(Error)An error occurred decoding ASN.1 data.
The content-type attribute is missing from the SignedAttributes structure.
The content-type attribute in the SignedAttributes structure is malformed.
The message-digest attribute is missed from the SignedAttributes structure.
The message-digest attribute is malformed.
The signing-time signed attribute is malformed.
The time-stamp token unsigned attribute is malformed.
Subject key identifiers in signer info is not supported.
Io(Error)A general I/O error occurred.
UnknownKeyAlgorithm(Oid)An unknown signing key algorithm was encountered.
UnknownDigestAlgorithm(Oid)An unknown message digest algorithm was encountered.
UnknownSignatureAlgorithm(Oid)An unknown signature algorithm was encountered.
An unknown certificate format was encountered.
A certificate was not found.
Signature verification fail.
No SignedAttributes were present when they should have been.
Two content digests were not equivalent.
Pem(PemError)Error encoding/decoding PEM data.
Error occurred when creating a signature.
Attempted to use a Certificate but we couldn’t find the backing data for it.
Error occurred parsing a distinguished name field in a certificate.
TimeStampProtocol(TimeStampError)Error occurred in Time-Stamp Protocol.
X509Certificate(X509CertificateError)Error occurred in the x509-certificate crate.